<html>
    <head>
      <title>{{ title }} - Archivy</title>
	  <meta name="viewport" content="width=device-width, initial-scale=1.0">
      <link rel="stylesheet" href="{{ url_for('static', filename='main.css') }}">
      <link rel="stylesheet" href="{{ url_for('static', filename='mvp.css') }}">
    </head>
    <body>
        <main class="content">
            <div><a href="/index">Home</a></div>
            <h1>Archivy</h1>
            {% with messages = get_flashed_messages() %}
                {% if messages %}
                    <ul>
                        {% for message in messages %}
                            <li>{{ message }}</li>
                        {% endfor %}
                    </ul>
                {% endif %}
            {% endwith %}
            {% block content %}{% endblock %}
        </main>
    </body>
</html>
