.content {
  width: 50%;
  margin: auto;
}

.hidden {
  display: none;
}

.fadein {
  transition: opacity 1s;
  opacity: 1;
  display: flex !important;
}

.new-folder {
  align-items: center;
  flex-wrap: wrap;
  border: none;
}
.new-folder > * {
  margin: 0px 10px;
}
.new-folder input {
  margin: 0px;
}
.new-folder input[type="submit"] {
  padding: 5px;
  margin: 0px 10px;
}

.delete-btn {
  padding: 0;
  border: none;
  background: none;
}
.delete-btn img {
  height: 40px;
}

.expand-btn {
  background: none;
  padding: 0;
  border: none;
  color: #920de9;
}

.folder-cont {
  border-left: 5px solid #ff4301;
  padding: 0px 10px;
  margin: 50px 0px;
}
.folder-cont h2,
.folder-cont p {
  margin: 5px;
}
.folder-cont ul {
  display: none;
}
.folder-cont form {
  display: none;
}

@media only screen and (max-width: 500px) {
  .content {
    width: 90%;
  }
}
